@@ -9,7 +9,7 @@ testDataFolder <- file.path(testthat::test_path(), "testData")
 ##############################################################################################
 
 test_that("test of simple timeseries request with relative dates", {
-  if(Sys.getenv("DatastreamUsername") == ""){
+  if (Sys.getenv("DatastreamUsername") == "") {
     skip("Username not available")
   }
   skip_on_cran()
@@ -35,7 +35,7 @@ test_that("test of simple timeseries request with relative dates", {
 ##############################################################################################
 
 test_that("test of two stock timeseries request with relative dates", {
-  if(Sys.getenv("DatastreamUsername") == ""){
+  if (Sys.getenv("DatastreamUsername") == "") {
     skip("Username not available")
   }
   skip_on_cran()
@@ -61,7 +61,7 @@ test_that("test of two stock timeseries request with relative dates", {
 ##############################################################################################
 
 test_that("test of simple timeseries request with absolute dates", {
-  if(Sys.getenv("DatastreamUsername") == ""){
+  if (Sys.getenv("DatastreamUsername") == "") {
     skip("Username not available")
   }
   skip_on_cran()
@@ -84,7 +84,7 @@ test_that("test of simple timeseries request with absolute dates", {
 ##############################################################################################
 
 test_that("test of two stock timeseries request with absolute dates", {
-  if(Sys.getenv("DatastreamUsername") == ""){
+  if (Sys.getenv("DatastreamUsername") == "") {
     skip("Username not available")
   }
   skip_on_cran()
@@ -105,7 +105,7 @@ test_that("test of two stock timeseries request with absolute dates", {
 
 #######################################################################################
 test_that("test of the instrument being an expression with economic data", {
-  if(Sys.getenv("DatastreamUsername") == ""){
+  if (Sys.getenv("DatastreamUsername") == "") {
     skip("Username not available")
   }
   skip_on_cran()
@@ -123,10 +123,34 @@ test_that("test of the instrument being an expression with economic data", {
 
   rm(mydsws, xtsData)
 
+})
+#######################################################################################
+test_that("test that no warnings are produce", {
+  if (Sys.getenv("DatastreamUsername") == "") {
+    skip("Username not available")
+  }
+  skip_on_cran()
+
+
+  mydsws <- dsws$new()
+  expect_silent({
+    xtsData <- mydsws$timeSeriesRequest(instrument = c("MSACWF$(RI)/MLGALML(RI)",
+                                                       "TOTMKUS(RI)/BMUS10Y(RI)"),
+                                        datatype = "NAME",
+                                        startDate = as.Date("2022-04-27"),
+                                        endDate = as.Date("2022-04-27"),
+                                        frequency = "D")
+
+  })
+  expect_is(xtsData, "xts")
+  expect_equal(nrow(xtsData), 0)
+  expect_equal(ncol(xtsData), 2)
+  rm(mydsws, xtsData)
+
 })
 #######################################################################################
 test_that("test of the instrument being an expression with economic data but call with wrong periodicity", {
-  if(Sys.getenv("DatastreamUsername") == ""){
+  if (Sys.getenv("DatastreamUsername") == "") {
     skip("Username not available")
   }
   skip_on_cran()
@@ -148,7 +172,7 @@ test_that("test of the instrument being an expression with economic data but cal
 
 ##############################################################################
 test_that("test of three stock request", {
-  if(Sys.getenv("DatastreamUsername") == ""){
+  if (Sys.getenv("DatastreamUsername") == "") {
     skip("Username not available")
   }
   skip_on_cran()
@@ -169,7 +193,7 @@ test_that("test of three stock request", {
 
 ##############################################################################################
 test_that("test of multi stock timeseries request with an expression as the datatype", {
-  if(Sys.getenv("DatastreamUsername") == ""){
+  if (Sys.getenv("DatastreamUsername") == "") {
     skip("Username not available")
   }
   skip_on_cran()
@@ -191,7 +215,7 @@ test_that("test of multi stock timeseries request with an expression as the data
 
 #############################################################
 test_that("test of download worldscope data - this data is numeric", {
-  if(Sys.getenv("DatastreamUsername") == ""){
+  if (Sys.getenv("DatastreamUsername") == "") {
     skip("Username not available")
   }
   skip_on_cran()
@@ -214,7 +238,7 @@ test_that("test of download worldscope data - this data is numeric", {
 
 #############################################################
 test_that("test of lowercase RIC Codes", {
-  if(Sys.getenv("DatastreamUsername") == ""){
+  if (Sys.getenv("DatastreamUsername") == "") {
     skip("Username not available")
   }
   skip_on_cran()
@@ -239,7 +263,7 @@ test_that("test of lowercase RIC Codes", {
 
 #############################################################
 test_that("test of download worldscope data - this data is Dates", {
-  if(Sys.getenv("DatastreamUsername") == ""){
+  if (Sys.getenv("DatastreamUsername") == "") {
     skip("Username not available")
   }
   skip_on_cran()
@@ -265,7 +289,7 @@ test_that("test of download worldscope data - this data is Dates", {
 
 #############################################################
 test_that("test of download worldscope data for multiple stocks", {
-  if(Sys.getenv("DatastreamUsername") == ""){
+  if (Sys.getenv("DatastreamUsername") == "") {
     skip("Username not available")
   }
   skip_on_cran()
@@ -286,7 +310,7 @@ test_that("test of download worldscope data for multiple stocks", {
 
 #############################################################
 test_that("test of Datastream expression eg 045E(XXXX)", {
-  if(Sys.getenv("DatastreamUsername") == ""){
+  if (Sys.getenv("DatastreamUsername") == "") {
     skip("Username not available")
   }
   skip_on_cran()
@@ -307,7 +331,7 @@ test_that("test of Datastream expression eg 045E(XXXX)", {
 
 #############################################################
 test_that("test of ISIN code and expression that was not being returned", {
-  if(Sys.getenv("DatastreamUsername") == ""){
+  if (Sys.getenv("DatastreamUsername") == "") {
     skip("Username not available")
   }
   skip_on_cran()
@@ -334,7 +358,7 @@ test_that("test of ISIN code and expression that was not being returned", {
 #############################################################
 #
 # test_that("test of selecting stocks via ISIN codes with missing (NA) codes and expressions", {
-#   if(is.null(options()$Datastream.Username)){
+#   if (is.null(options()$Datastream.Username)) {
 #     skip("Username not available")
 #   }
 #   skip_on_cran()
@@ -355,7 +379,7 @@ test_that("test of ISIN code and expression that was not being returned", {
 #############################################################
 
 test_that("test of selecting stocks via ISIN codes with missing (NA) codes and expressions", {
-  if(Sys.getenv("DatastreamUsername") == ""){
+  if (Sys.getenv("DatastreamUsername") == "") {
     skip("Username not available")
   }
   skip_on_cran()
@@ -377,31 +401,31 @@ test_that("test of selecting stocks via ISIN codes with missing (NA) codes and e
 
 #############################################################
 test_that("test of selecting stocks via ISIN codes with missing (NA) codes ", {
-if(Sys.getenv("DatastreamUsername") == ""){
-  skip("Username not available")
-}
-skip_on_cran()
+  if (Sys.getenv("DatastreamUsername") == "") {
+    skip("Username not available")
+  }
+  skip_on_cran()
 
 
-DSCodes <- c("JP3735400008", NA, "JP3305990008", "JP3117700009")
-startDate <- as.Date("1994-12-02")
-endDate <- as.Date("2018-01-23")
-mydsws <- dsws$new()
-xtsRepDates <- mydsws$timeSeriesRequest(instrument = DSCodes,
-                                        expression =  "XXXX(WC05905A)",
-                                        startDate = startDate,
-                                        endDate = endDate,
-                                        frequency = "D",
-                                        format = "ByInstrument")
+  DSCodes <- c("JP3735400008", NA, "JP3305990008", "JP3117700009")
+  startDate <- as.Date("1994-12-02")
+  endDate <- as.Date("2018-01-23")
+  mydsws <- dsws$new()
+  xtsRepDates <- mydsws$timeSeriesRequest(instrument = DSCodes,
+                                          expression =  "XXXX(WC05905A)",
+                                          startDate = startDate,
+                                          endDate = endDate,
+                                          frequency = "D",
+                                          format = "ByInstrument")
 
-naRepDates <- xtsRepDates[ , 2]
-expect_false(FALSE %in% is.na(naRepDates))
+  naRepDates <- xtsRepDates[ , 2]
+  expect_false(FALSE %in% is.na(naRepDates))
 
 })
 #############################################################
 
 test_that("test of selecting stocks via ISIN codes with the first code missing and expressions", {
-  if(Sys.getenv("DatastreamUsername") == ""){
+  if (Sys.getenv("DatastreamUsername") == "") {
     skip("Username not available")
   }
   skip_on_cran()
@@ -428,31 +452,31 @@ test_that("further test of missing stocks ", {
   # the correct response should be an xts with a column per instrument
   # and a single row (dated endDate) that has NA's in it.
 
-  if(Sys.getenv("DatastreamUsername") == ""){
-  skip("Username not available")
-}
-skip_on_cran()
+  if (Sys.getenv("DatastreamUsername") == "") {
+    skip("Username not available")
+  }
+  skip_on_cran()
 
-mydsws <- dsws$new()
-xtsData <- mydsws$timeSeriesRequest(instrument = c("CA91911K1021","US8552441094","VEV0019410A9",
-                                                   "US5007541064","US4385161066"),
-                                    expression = "XXXX(BPS1TR12)/XXXX",
-                                    startDate = as.Date("2016-01-30"),
-                                    endDate = as.Date("2016-02-01"),
-                                    frequency = "D")
+  mydsws <- dsws$new()
+  xtsData <- mydsws$timeSeriesRequest(instrument = c("CA91911K1021","US8552441094","VEV0019410A9",
+                                                     "US5007541064","US4385161066"),
+                                      expression = "XXXX(BPS1TR12)/XXXX",
+                                      startDate = as.Date("2016-01-30"),
+                                      endDate = as.Date("2016-02-01"),
+                                      frequency = "D")
 
-expect_is(xtsData, "xts")
-expect_equal(ncol(xtsData), 5L)
-expect_equal(nrow(xtsData), 2L)
-expect_true(TRUE %in% is.na(xtsData[1,]))
+  expect_is(xtsData, "xts")
+  expect_equal(ncol(xtsData), 5L)
+  expect_equal(nrow(xtsData), 2L)
+  expect_true(TRUE %in% is.na(xtsData[1,]))
 
-rm(mydsws, xtsData)
+  rm(mydsws, xtsData)
 
 })
 
 #############################################################
 test_that("test of Japanese ISIN with PE", {
-  if(Sys.getenv("DatastreamUsername") == ""){
+  if (Sys.getenv("DatastreamUsername") == "") {
     skip("Username not available")
   }
   skip_on_cran()
@@ -473,7 +497,7 @@ test_that("test of Japanese ISIN with PE", {
 
 ##############################################################################################
 test_that("test of ISIN returns Failure, status code 2, message $$\"ER\", 0904, NO DATA AVAILABLE", {
-  if(Sys.getenv("DatastreamUsername") == ""){
+  if (Sys.getenv("DatastreamUsername") == "") {
     skip("Username not available")
   }
   skip_on_cran()
@@ -496,7 +520,7 @@ test_that("test of ISIN returns Failure, status code 2, message $$\"ER\", 0904,
 # This is a mixture of NO DATA AVAILABLE and valid data
 #
 test_that("test of ISIN returns mixture of NO DATA AVAILABLE and valid data", {
-  if(Sys.getenv("DatastreamUsername") == ""){
+  if (Sys.getenv("DatastreamUsername") == "") {
     skip("Username not available")
   }
   skip_on_cran()
@@ -519,7 +543,7 @@ test_that("test of ISIN returns mixture of NO DATA AVAILABLE and valid data", {
 # This is a test of chunked requests - first make an unchunked one, and then a chunked one
 #
 test_that("test of chunked timeSeriesRequests with a datatype", {
-  if(Sys.getenv("DatastreamUsername") == ""){
+  if (Sys.getenv("DatastreamUsername") == "") {
     skip("Username not available")
   }
   skip_on_cran()
@@ -560,7 +584,7 @@ test_that("test of chunked timeSeriesRequests with a datatype", {
 # This is a test of chunked requests - first make an unchunked one, and then a chunked one
 #
 test_that("test of chunked timeSeriesRequests with an expression", {
-  if(Sys.getenv("DatastreamUsername") == ""){
+  if (Sys.getenv("DatastreamUsername") == "") {
     skip("Username not available")
   }
   skip_on_cran()
@@ -602,7 +626,7 @@ test_that("test of chunked timeSeriesRequests with an expression", {
 # This is a test of setting chunkLimit via options()
 #
 test_that("test of setting chunkLimit via options()", {
-  if(Sys.getenv("DatastreamUsername") == ""){
+  if (Sys.getenv("DatastreamUsername") == "") {
     skip("Username not available")
   }
   skip_on_cran()
@@ -622,27 +646,27 @@ test_that("test of setting chunkLimit via options()", {
 # This is a test that if a chunk returns all NA it does not 'poison' the other chunks
 #
 test_that("test of single chunk returning NA", {
-  if(Sys.getenv("DatastreamUsername") == ""){
+  if (Sys.getenv("DatastreamUsername") == "") {
     skip("Username not available")
   }
   skip_on_cran()
 
-endDate = as.Date("2019-04-26")
-expression = "HIDE#(XXXX(NERI0YR))"
-frequency = "D"
-startDate = as.Date("2019-04-26")
+  endDate = as.Date("2019-04-26")
+  expression = "HIDE#(XXXX(NERI0YR))"
+  frequency = "D"
+  startDate = as.Date("2019-04-26")
 
-stocks <- readRDS(file.path(testDataFolder, "Europe600Codes.rds"))
+  stocks <- readRDS(file.path(testDataFolder, "Europe600Codes.rds"))
 
-mydsws <- dsws$new()
-#mydsws$logging <- 60L
-myDF <- mydsws$timeSeriesRequest(instrument = stocks,
-                                 expression = expression,
-                                 startDate = startDate,
-                                 endDate = endDate,
-                                 frequency = frequency)
+  mydsws <- dsws$new()
+  #mydsws$logging <- 60L
+  myDF <- mydsws$timeSeriesRequest(instrument = stocks,
+                                   expression = expression,
+                                   startDate = startDate,
+                                   endDate = endDate,
+                                   frequency = frequency)
 
-expect_true(sum(!is.na(myDF)) > 0)
+  expect_true(sum(!is.na(myDF)) > 0)
 })
 
 ##############################################################################################
@@ -650,7 +674,7 @@ expect_true(sum(!is.na(myDF)) > 0)
 #
 
 test_that("test of chunking timeSeriesRequests due to request string length", {
-  if(Sys.getenv("DatastreamUsername") == ""){
+  if (Sys.getenv("DatastreamUsername") == "") {
     skip("Username not available")
   }
   skip_on_cran()
@@ -695,7 +719,7 @@ test_that("test of chunking timeSeriesRequests due to request string length", {
 #
 
 test_that("test of named instruments, datatypes and expressions", {
-  if(Sys.getenv("DatastreamUsername") == ""){
+  if (Sys.getenv("DatastreamUsername") == "") {
     skip("Username not available")
   }
   skip_on_cran()
@@ -737,7 +761,7 @@ test_that("test of named instruments, datatypes and expressions", {
 #
 
 test_that("test of chunking timeSeriesRequests due to request string length", {
-  if(Sys.getenv("DatastreamUsername") == ""){
+  if (Sys.getenv("DatastreamUsername") == "") {
     skip("Username not available")
   }
   skip_on_cran()
@@ -766,7 +790,7 @@ test_that("test of chunking timeSeriesRequests due to request string length", {
 #
 
 test_that("test of handling mainframe timeouts", {
-  if(Sys.getenv("DatastreamUsername") == ""){
+  if (Sys.getenv("DatastreamUsername") == "") {
     skip("Username not available")
   }
   skip_on_cran()
@@ -778,30 +802,30 @@ test_that("test of handling mainframe timeouts", {
   # Get the unchunked data
 
   instCodes <- c("PCH#(US88033G4073(EPS1TR12),3Y)/100.000", "PCH#(US87612E1064(EPS1TR12),3Y)/100.000",
-    "PCH#(US87901J1051(EPS1TR12),3Y)/100.000", "PCH#(US8723751009(EPS1TR12),3Y)/100.000",
-    "PCH#(US8794338298(EPS1TR12),3Y)/100.000", "PCH#(US8718291078(EPS1TR12),3Y)/100.000",
-    "PCH#(US8636671013(EPS1TR12),3Y)/100.000", "PCH#(US8711301007(EPS1TR12),3Y)/100.000",
-    "PCH#(US8581222036(EPS1TR12),3Y)/100.000", "PCH#(US7865142084(EPS1TR12),3Y)/100.000",
-    "PCH#(US8545021011(EPS1TR12),3Y)/100.000", "PCH#(US8685361037(EPS1TR12),3Y)/100.000",
-    "PCH#(US8574771031(EPS1TR12),3Y)/100.000", "PCH#(US7908491035(EPS1TR12),3Y)/100.000",
-    "PCH#(US8679141031(EPS1TR12),3Y)/100.000", "PCH#(US8110544025(EPS1TR12),3Y)/100.000",
-    "PCH#(US8550301027(EPS1TR12),3Y)/100.000", "PCH#(US8354951027(EPS1TR12),3Y)/100.000",
-    "PCH#(US8425871071(EPS1TR12),3Y)/100.000", "PCH#(US87161C5013(EPS1TR12),3Y)/100.000",
-    "PCH#(US78442P1066(EPS1TR12),3Y)/100.000", "PCH#(AN8068571086(EPS1TR12),3Y)/100.000",
-    "PCH#(US8265521018(EPS1TR12),3Y)/100.000", "PCH#(US8202861022(EPS1TR12),3Y)/100.000",
-    "PCH#(US8243481061(EPS1TR12),3Y)/100.000", "PCH#(US8066051017(EPS1TR12),3Y)/100.000",
-    "PCH#(US8270561025(EPS1TR12),3Y)/100.000", "PCH#(US8175651046(EPS1TR12),3Y)/100.000",
-    "PCH#(US8085131055(EPS1TR12),3Y)/100.000", "PCH#(US80589M1027(EPS1TR12),3Y)/100.000",
-    "PCH#(US7864291007(EPS1TR12),3Y)/100.000", "PCH#(US7551115071(EPS1TR12),3Y)/100.000",
-    "PCH#(US7504381036(EPS1TR12),3Y)/100.000", "PCH#(US2578671016(EPS1TR12),3Y)/100.000",
-    "PCH#(US7753711073(EPS1TR12),3Y)/100.000", "PCH#(US7617631012(EPS1TR12),3Y)/100.000",
-    "PCH#(US7591EP1005(EPS1TR12),3Y)/100.000", "PCH#(US7616951056(EPS1TR12),3Y)/100.000",
-    "PCH#(US0019201070(EPS1TR12),3Y)/100.000", "PCH#(US7581101000(EPS1TR12),3Y)/100.000",
-    "PCH#(US7512773026(EPS1TR12),3Y)/100.000", "PCH#(US7677541044(EPS1TR12),3Y)/100.000",
-    "PCH#(US7835491082(EPS1TR12),3Y)/100.000", "PCH#(US7475251036(EPS1TR12),3Y)/100.000",
-    "PCH#(US74005P1049(EPS1TR12),3Y)/100.000", "PCH#(US7310951055(EPS1TR12),3Y)/100.000",
-    "PCH#(US6951141083(EPS1TR12),3Y)/100.000", "PCH#(US69351T1060(EPS1TR12),3Y)/100.000",
-    "PCH#(US6935061076(EPS1TR12),3Y)/100.000")
+                 "PCH#(US87901J1051(EPS1TR12),3Y)/100.000", "PCH#(US8723751009(EPS1TR12),3Y)/100.000",
+                 "PCH#(US8794338298(EPS1TR12),3Y)/100.000", "PCH#(US8718291078(EPS1TR12),3Y)/100.000",
+                 "PCH#(US8636671013(EPS1TR12),3Y)/100.000", "PCH#(US8711301007(EPS1TR12),3Y)/100.000",
+                 "PCH#(US8581222036(EPS1TR12),3Y)/100.000", "PCH#(US7865142084(EPS1TR12),3Y)/100.000",
+                 "PCH#(US8545021011(EPS1TR12),3Y)/100.000", "PCH#(US8685361037(EPS1TR12),3Y)/100.000",
+                 "PCH#(US8574771031(EPS1TR12),3Y)/100.000", "PCH#(US7908491035(EPS1TR12),3Y)/100.000",
+                 "PCH#(US8679141031(EPS1TR12),3Y)/100.000", "PCH#(US8110544025(EPS1TR12),3Y)/100.000",
+                 "PCH#(US8550301027(EPS1TR12),3Y)/100.000", "PCH#(US8354951027(EPS1TR12),3Y)/100.000",
+                 "PCH#(US8425871071(EPS1TR12),3Y)/100.000", "PCH#(US87161C5013(EPS1TR12),3Y)/100.000",
+                 "PCH#(US78442P1066(EPS1TR12),3Y)/100.000", "PCH#(AN8068571086(EPS1TR12),3Y)/100.000",
+                 "PCH#(US8265521018(EPS1TR12),3Y)/100.000", "PCH#(US8202861022(EPS1TR12),3Y)/100.000",
+                 "PCH#(US8243481061(EPS1TR12),3Y)/100.000", "PCH#(US8066051017(EPS1TR12),3Y)/100.000",
+                 "PCH#(US8270561025(EPS1TR12),3Y)/100.000", "PCH#(US8175651046(EPS1TR12),3Y)/100.000",
+                 "PCH#(US8085131055(EPS1TR12),3Y)/100.000", "PCH#(US80589M1027(EPS1TR12),3Y)/100.000",
+                 "PCH#(US7864291007(EPS1TR12),3Y)/100.000", "PCH#(US7551115071(EPS1TR12),3Y)/100.000",
+                 "PCH#(US7504381036(EPS1TR12),3Y)/100.000", "PCH#(US2578671016(EPS1TR12),3Y)/100.000",
+                 "PCH#(US7753711073(EPS1TR12),3Y)/100.000", "PCH#(US7617631012(EPS1TR12),3Y)/100.000",
+                 "PCH#(US7591EP1005(EPS1TR12),3Y)/100.000", "PCH#(US7616951056(EPS1TR12),3Y)/100.000",
+                 "PCH#(US0019201070(EPS1TR12),3Y)/100.000", "PCH#(US7581101000(EPS1TR12),3Y)/100.000",
+                 "PCH#(US7512773026(EPS1TR12),3Y)/100.000", "PCH#(US7677541044(EPS1TR12),3Y)/100.000",
+                 "PCH#(US7835491082(EPS1TR12),3Y)/100.000", "PCH#(US7475251036(EPS1TR12),3Y)/100.000",
+                 "PCH#(US74005P1049(EPS1TR12),3Y)/100.000", "PCH#(US7310951055(EPS1TR12),3Y)/100.000",
+                 "PCH#(US6951141083(EPS1TR12),3Y)/100.000", "PCH#(US69351T1060(EPS1TR12),3Y)/100.000",
+                 "PCH#(US6935061076(EPS1TR12),3Y)/100.000")
 
   xtsTestData <- mydsws$timeSeriesRequest(instrument =  instCodes,
                                           expression = "",
@@ -824,7 +848,7 @@ test_that("test of handling mainframe timeouts", {
 
 
 test_that(" test of that if a single timeseries returns $$ER: 0904,NO DATA AVAILABLE", {
-  if(Sys.getenv("DatastreamUsername") == ""){
+  if (Sys.getenv("DatastreamUsername") == "") {
     skip("Username not available")
   }
   skip_on_cran()
@@ -835,10 +859,10 @@ test_that(" test of that if a single timeseries returns $$ER: 0904,NO DATA AVAIL
   # Get the unchunked data
 
   xtsActData <- mydsws$timeSeriesRequest(instrument = "KO:SGL",
-                                      datatype = "AX",
-                                      startDate = "2018-05-07",
-                                      endDate = "2018-05-09",
-                                      frequency = "D")
+                                         datatype = "AX",
+                                         startDate = "2018-05-07",
+                                         endDate = "2018-05-09",
+                                         frequency = "D")
   expect_is(xtsActData, "xts")
   expect_true(ncol(xtsActData) == 1)
   expect_true(nrow(xtsActData) == 0)
@@ -853,7 +877,7 @@ test_that(" test of that if a single timeseries returns $$ER: 0904,NO DATA AVAIL
 
 
 test_that("equest two timeseries and the first returns $$ER: 0904,NO DATA AVAILABLE", {
-  if(Sys.getenv("DatastreamUsername") == ""){
+  if (Sys.getenv("DatastreamUsername") == "") {
     skip("Username not available")
   }
   skip_on_cran()
@@ -883,7 +907,7 @@ test_that("equest two timeseries and the first returns $$ER: 0904,NO DATA AVAILA
 
 
 test_that("test of that if a we request two timeseries and the second returns $$ER: 0904,NO DATA AVAILABLE", {
-  if(Sys.getenv("DatastreamUsername") == ""){
+  if (Sys.getenv("DatastreamUsername") == "") {
     skip("Username not available")
   }
   skip_on_cran()
@@ -912,7 +936,7 @@ test_that("test of that if a we request two timeseries and the second returns $$
 
 
 test_that(" test of that if a single timeseries returns $$ER: 0904,NO DATA AVAILABLE", {
-  if(Sys.getenv("DatastreamUsername") == ""){
+  if (Sys.getenv("DatastreamUsername") == "") {
     skip("Username not available")
   }
   skip_on_cran()
